@@ -86,6 +86,18 @@ class CfLogSqliteModel(CfLogSqliteConnection):
     #    logger.debug(results)
     #    return results
 
+    def exists(self, where=None):
+        """Does the query return results?
+
+        Args:
+            where: SQL WHERE to filter data.
+        """
+        self.read_records(where=where)
+        if len(self.result) == 0:
+            return False
+        else:
+            return True
+
     def read_records(self, where=None):
         """Produce record entries.
 
@@ -95,7 +107,7 @@ class CfLogSqliteModel(CfLogSqliteConnection):
         sql = f'SELECT * FROM {self.table}'
 
         if where is not None:
-            sql += ' WHERE {where}'
+            sql += f' WHERE {where}'
 
         logger.debug(sql)
         self.execute(sql)
